@@ -52,8 +52,10 @@ class ASR:
         input_dict = self.processor(a["input_values"][0], return_tensors="pt", padding=True)
         logits = self.model(input_dict.input_values).logits
         pred_ids = torch.argmax(logits, dim=-1)[0]
-
-        txt = self.processor.batch_decode(logits.detach().numpy()).text[0]
+        if self.model_name == "airesearch/wav2vec2-large-xlsr-53-th":
+            txt = self.processor.decode(pred_ids).replace(' ','')
+        else:
+            txt = self.processor.batch_decode(logits.detach().numpy()).text[0]
         return txt
 
 _model_name = "airesearch/wav2vec2-large-xlsr-53-th"
